pub struct DiffBatch(/* private fields */);Implementations
Sourceimpl DiffBatch
impl DiffBatch
pub fn new() -> Self
Sourcepub fn push(&self, cid: ContainerID, diff: Diff) -> Option<Diff>
pub fn push(&self, cid: ContainerID, diff: Diff) -> Option<Diff>
Push a new event to the batch.
If the cid already exists in the batch, return Err
Sourcepub fn get_diff(&self) -> Vec<ContainerIDAndDiff>
pub fn get_diff(&self) -> Vec<ContainerIDAndDiff>
Returns an iterator over the diffs in this batch, in the order they were added.
The iterator yields tuples of (&ContainerID, &Diff) where:
ContainerIDis the ID of the container that was modifiedDiffcontains the actual changes made to that container
The order of the diffs is preserved from when they were originally added to the batch.