pub struct LoroCounter { /* private fields */ }Implementations
Sourceimpl LoroCounter
impl LoroCounter
pub fn new() -> Self
Sourcepub fn is_attached(&self) -> bool
pub fn is_attached(&self) -> bool
Whether the container is attached to a document
The edits on a detached container will not be persisted. To attach the container to the document, please insert it into an attached container.
Sourcepub fn get_attached(&self) -> Option<Arc<LoroCounter>>
pub fn get_attached(&self) -> Option<Arc<LoroCounter>>
If a detached container is attached, this method will return its corresponding attached handler.
Sourcepub fn id(&self) -> ContainerID
pub fn id(&self) -> ContainerID
Return container id of the Counter.
Sourcepub fn increment(&self, value: f64) -> LoroResult<()>
pub fn increment(&self, value: f64) -> LoroResult<()>
Increment the counter by the given value.
Sourcepub fn decrement(&self, value: f64) -> LoroResult<()>
pub fn decrement(&self, value: f64) -> LoroResult<()>
Decrement the counter by the given value.
pub fn is_deleted(&self) -> bool
pub fn doc(&self) -> Option<Arc<LoroDoc>>
pub fn subscribe( &self, subscriber: Arc<dyn Subscriber>, ) -> Option<Arc<Subscription>>