pub struct LoroMap { /* private fields */ }Implementations
Sourceimpl LoroMap
impl LoroMap
pub fn new() -> Self
pub fn is_attached(&self) -> bool
Sourcepub fn get_attached(&self) -> Option<Arc<LoroMap>>
pub fn get_attached(&self) -> Option<Arc<LoroMap>>
If a detached container is attached, this method will return its corresponding attached handler.
Sourcepub fn delete(&self, key: &str) -> LoroResult<()>
pub fn delete(&self, key: &str) -> LoroResult<()>
Delete a key-value pair from the map.
Sourcepub fn insert(&self, key: &str, value: Arc<dyn LoroValueLike>) -> LoroResult<()>
pub fn insert(&self, key: &str, value: Arc<dyn LoroValueLike>) -> LoroResult<()>
Iterate over the key-value pairs of the map. Insert a key-value pair into the map.
Sourcepub fn id(&self) -> ContainerID
pub fn id(&self) -> ContainerID
Get the ID of the map.
Sourcepub fn get(&self, key: &str) -> Option<Arc<dyn ValueOrContainer>>
pub fn get(&self, key: &str) -> Option<Arc<dyn ValueOrContainer>>
Get the value of the map with the given key.
pub fn get_or_create_text_container( &self, key: &str, text: Arc<LoroText>, ) -> LoroResult<Arc<LoroText>>
pub fn get_or_create_map_container( &self, key: &str, map: Arc<LoroMap>, ) -> LoroResult<Arc<LoroMap>>
pub fn get_or_create_tree_container( &self, key: &str, tree: Arc<LoroTree>, ) -> LoroResult<Arc<LoroTree>>
pub fn get_or_create_list_container( &self, key: &str, list: Arc<LoroList>, ) -> LoroResult<Arc<LoroList>>
pub fn get_or_create_movable_list_container( &self, key: &str, list: Arc<LoroMovableList>, ) -> LoroResult<Arc<LoroMovableList>>
pub fn get_or_create_counter_container( &self, key: &str, counter: Arc<LoroCounter>, ) -> LoroResult<Arc<LoroCounter>>
pub fn insert_list_container( &self, key: &str, child: Arc<LoroList>, ) -> LoroResult<Arc<LoroList>>
pub fn insert_map_container( &self, key: &str, child: Arc<LoroMap>, ) -> LoroResult<Arc<LoroMap>>
pub fn insert_text_container( &self, key: &str, child: Arc<LoroText>, ) -> LoroResult<Arc<LoroText>>
pub fn insert_tree_container( &self, key: &str, child: Arc<LoroTree>, ) -> LoroResult<Arc<LoroTree>>
pub fn insert_movable_list_container( &self, key: &str, child: Arc<LoroMovableList>, ) -> LoroResult<Arc<LoroMovableList>>
pub fn insert_counter_container( &self, key: &str, child: Arc<LoroCounter>, ) -> LoroResult<Arc<LoroCounter>>
Sourcepub fn get_value(&self) -> LoroValue
pub fn get_value(&self) -> LoroValue
Get the shallow value of the map.
It will not convert the state of sub-containers, but represent them as LoroValue::Container.
Sourcepub fn get_deep_value(&self) -> LoroValue
pub fn get_deep_value(&self) -> LoroValue
Get the deep value of the map.
It will convert the state of sub-containers into a nested JSON value.
pub fn is_deleted(&self) -> bool
pub fn get_last_editor(&self, key: &str) -> Option<PeerID>
pub fn clear(&self) -> LoroResult<()>
pub fn keys(&self) -> Vec<String>
pub fn values(&self) -> Vec<Arc<dyn ValueOrContainer>>
pub fn doc(&self) -> Option<Arc<LoroDoc>>
pub fn subscribe( &self, subscriber: Arc<dyn Subscriber>, ) -> Option<Arc<Subscription>>