LoroMovableList

Struct LoroMovableList 

pub struct LoroMovableList { /* private fields */ }

Implementations

Source

impl LoroMovableList

pub fn new() -> Self

pub fn id(&self) -> ContainerID

Get the container id.

pub fn is_attached(&self) -> bool

Whether the container is attached to a document

The edits on a detached container will not be persisted. To attach the container to the document, please insert it into an attached container.

pub fn get_attached(&self) -> Option<Arc<LoroMovableList>>

If a detached container is attached, this method will return its corresponding attached handler.

pub fn insert(&self, pos: u32, v: Arc<dyn LoroValueLike>) -> LoroResult<()>

Insert a value at the given position.

pub fn delete(&self, pos: u32, len: u32) -> LoroResult<()>

Delete values at the given position.

pub fn get(&self, index: u32) -> Option<Arc<dyn ValueOrContainer>>

Get the value at the given position.

pub fn len(&self) -> u32

Get the length of the list.

pub fn is_empty(&self) -> bool

Whether the list is empty.

pub fn get_value(&self) -> LoroValue

Get the shallow value of the list.

It will not convert the state of sub-containers, but represent them as LoroValue::Container.

pub fn get_deep_value(&self) -> LoroValue

Get the deep value of the list.

It will convert the state of sub-containers into a nested JSON value.

pub fn pop(&self) -> LoroResult<Option<Arc<dyn ValueOrContainer>>>

Pop the last element of the list.

pub fn push(&self, v: Arc<dyn LoroValueLike>) -> LoroResult<()>

pub fn insert_list_container( &self, pos: u32, child: Arc<LoroList>, ) -> LoroResult<Arc<LoroList>>

pub fn insert_map_container( &self, pos: u32, child: Arc<LoroMap>, ) -> LoroResult<Arc<LoroMap>>

pub fn insert_text_container( &self, pos: u32, child: Arc<LoroText>, ) -> LoroResult<Arc<LoroText>>

pub fn insert_tree_container( &self, pos: u32, child: Arc<LoroTree>, ) -> LoroResult<Arc<LoroTree>>

pub fn insert_movable_list_container( &self, pos: u32, child: Arc<LoroMovableList>, ) -> LoroResult<Arc<LoroMovableList>>

pub fn insert_counter_container( &self, pos: u32, child: Arc<LoroCounter>, ) -> LoroResult<Arc<LoroCounter>>

pub fn set_list_container( &self, pos: u32, child: Arc<LoroList>, ) -> LoroResult<Arc<LoroList>>

pub fn set_map_container( &self, pos: u32, child: Arc<LoroMap>, ) -> LoroResult<Arc<LoroMap>>

pub fn set_text_container( &self, pos: u32, child: Arc<LoroText>, ) -> LoroResult<Arc<LoroText>>

pub fn set_tree_container( &self, pos: u32, child: Arc<LoroTree>, ) -> LoroResult<Arc<LoroTree>>

pub fn set_movable_list_container( &self, pos: u32, child: Arc<LoroMovableList>, ) -> LoroResult<Arc<LoroMovableList>>

pub fn set_counter_container( &self, pos: u32, child: Arc<LoroCounter>, ) -> LoroResult<Arc<LoroCounter>>

pub fn set(&self, pos: u32, value: Arc<dyn LoroValueLike>) -> LoroResult<()>

Set the value at the given position.

pub fn mov(&self, from: u32, to: u32) -> LoroResult<()>

Move the value at the given position to the given position.

pub fn get_cursor(&self, pos: u32, side: Side) -> Option<Arc<Cursor>>

Get the cursor at the given position.

Using “index” to denote cursor positions can be unstable, as positions may shift with document edits. To reliably represent a position or range within a document, it is more effective to leverage the unique ID of each item/character in a List CRDT or Text CRDT.

Loro optimizes State metadata by not storing the IDs of deleted elements. This approach complicates tracking cursors since they rely on these IDs. The solution recalculates position by replaying relevant history to update stable positions accurately. To minimize the performance impact of history replay, the system updates cursor info to reference only the IDs of currently present elements, thereby reducing the need for replay.

pub fn to_vec(&self) -> Vec<LoroValue>

pub fn clear(&self) -> LoroResult<()>

pub fn is_deleted(&self) -> bool

pub fn get_creator_at(&self, index: u32) -> Option<PeerID>

pub fn get_last_mover_at(&self, index: u32) -> Option<PeerID>

pub fn get_last_editor_at(&self, index: u32) -> Option<PeerID>

pub fn doc(&self) -> Option<Arc<LoroDoc>>

pub fn subscribe( &self, subscriber: Arc<dyn Subscriber>, ) -> Option<Arc<Subscription>>