UndoManager

Struct UndoManager 

pub struct UndoManager(/* private fields */);

Implementations

Source

impl UndoManager

pub fn new(doc: &LoroDoc) -> Self

Create a new UndoManager.

pub fn undo(&self) -> LoroResult<bool>

Undo the last change made by the peer.

pub fn redo(&self) -> LoroResult<bool>

Redo the last change made by the peer.

pub fn record_new_checkpoint(&self) -> LoroResult<()>

Record a new checkpoint.

pub fn can_undo(&self) -> bool

Whether the undo manager can undo.

pub fn can_redo(&self) -> bool

Whether the undo manager can redo.

pub fn undo_count(&self) -> u32

How many times the undo manager can undo.

pub fn redo_count(&self) -> u32

How many times the undo manager can redo.

pub fn add_exclude_origin_prefix(&self, prefix: &str)

If a local event’s origin matches the given prefix, it will not be recorded in the undo stack.

pub fn set_max_undo_steps(&self, size: u32)

Set the maximum number of undo steps. The default value is 100.

pub fn set_merge_interval(&self, interval: i64)

Set the merge interval in ms. The default value is 0, which means no merge.

pub fn set_on_push(&self, on_push: Option<Arc<dyn OnPush>>)

Set the listener for push events. The listener will be called when a new undo/redo item is pushed into the stack.

pub fn set_on_pop(&self, on_pop: Option<Arc<dyn OnPop>>)

Set the listener for pop events. The listener will be called when an undo/redo item is popped from the stack.

pub fn group_start(&self) -> LoroResult<()>

pub fn group_end(&self)

pub fn peer(&self) -> PeerID

pub fn top_undo_meta(&self) -> Option<UndoItemMeta>

pub fn top_redo_meta(&self) -> Option<UndoItemMeta>

pub fn top_undo_value(&self) -> Option<LoroValue>

pub fn top_redo_value(&self) -> Option<LoroValue>