pub struct LoroMovableList { /* private fields */ }Implementations
Sourceimpl LoroMovableList
impl LoroMovableList
pub fn new() -> Self
Sourcepub fn id(&self) -> ContainerID
pub fn id(&self) -> ContainerID
Get the container id.
Sourcepub fn is_attached(&self) -> bool
pub fn is_attached(&self) -> bool
Whether the container is attached to a document
The edits on a detached container will not be persisted. To attach the container to the document, please insert it into an attached container.
Sourcepub fn get_attached(&self) -> Option<Arc<LoroMovableList>>
pub fn get_attached(&self) -> Option<Arc<LoroMovableList>>
If a detached container is attached, this method will return its corresponding attached handler.
Sourcepub fn insert(&self, pos: u32, v: Arc<dyn LoroValueLike>) -> LoroResult<()>
pub fn insert(&self, pos: u32, v: Arc<dyn LoroValueLike>) -> LoroResult<()>
Insert a value at the given position.
Sourcepub fn delete(&self, pos: u32, len: u32) -> LoroResult<()>
pub fn delete(&self, pos: u32, len: u32) -> LoroResult<()>
Delete values at the given position.
Sourcepub fn get(&self, index: u32) -> Option<Arc<dyn ValueOrContainer>>
pub fn get(&self, index: u32) -> Option<Arc<dyn ValueOrContainer>>
Get the value at the given position.
Sourcepub fn get_value(&self) -> LoroValue
pub fn get_value(&self) -> LoroValue
Get the shallow value of the list.
It will not convert the state of sub-containers, but represent them as LoroValue::Container.
Sourcepub fn get_deep_value(&self) -> LoroValue
pub fn get_deep_value(&self) -> LoroValue
Get the deep value of the list.
It will convert the state of sub-containers into a nested JSON value.
Sourcepub fn pop(&self) -> LoroResult<Option<Arc<dyn ValueOrContainer>>>
pub fn pop(&self) -> LoroResult<Option<Arc<dyn ValueOrContainer>>>
Pop the last element of the list.
pub fn push(&self, v: Arc<dyn LoroValueLike>) -> LoroResult<()>
pub fn insert_list_container( &self, pos: u32, child: Arc<LoroList>, ) -> LoroResult<Arc<LoroList>>
pub fn insert_map_container( &self, pos: u32, child: Arc<LoroMap>, ) -> LoroResult<Arc<LoroMap>>
pub fn insert_text_container( &self, pos: u32, child: Arc<LoroText>, ) -> LoroResult<Arc<LoroText>>
pub fn insert_tree_container( &self, pos: u32, child: Arc<LoroTree>, ) -> LoroResult<Arc<LoroTree>>
pub fn insert_movable_list_container( &self, pos: u32, child: Arc<LoroMovableList>, ) -> LoroResult<Arc<LoroMovableList>>
pub fn insert_counter_container( &self, pos: u32, child: Arc<LoroCounter>, ) -> LoroResult<Arc<LoroCounter>>
pub fn set_list_container( &self, pos: u32, child: Arc<LoroList>, ) -> LoroResult<Arc<LoroList>>
pub fn set_map_container( &self, pos: u32, child: Arc<LoroMap>, ) -> LoroResult<Arc<LoroMap>>
pub fn set_text_container( &self, pos: u32, child: Arc<LoroText>, ) -> LoroResult<Arc<LoroText>>
pub fn set_tree_container( &self, pos: u32, child: Arc<LoroTree>, ) -> LoroResult<Arc<LoroTree>>
pub fn set_movable_list_container( &self, pos: u32, child: Arc<LoroMovableList>, ) -> LoroResult<Arc<LoroMovableList>>
pub fn set_counter_container( &self, pos: u32, child: Arc<LoroCounter>, ) -> LoroResult<Arc<LoroCounter>>
Sourcepub fn set(&self, pos: u32, value: Arc<dyn LoroValueLike>) -> LoroResult<()>
pub fn set(&self, pos: u32, value: Arc<dyn LoroValueLike>) -> LoroResult<()>
Set the value at the given position.
Sourcepub fn mov(&self, from: u32, to: u32) -> LoroResult<()>
pub fn mov(&self, from: u32, to: u32) -> LoroResult<()>
Move the value at the given position to the given position.
Sourcepub fn get_cursor(&self, pos: u32, side: Side) -> Option<Arc<Cursor>>
pub fn get_cursor(&self, pos: u32, side: Side) -> Option<Arc<Cursor>>
Get the cursor at the given position.
Using “index” to denote cursor positions can be unstable, as positions may shift with document edits. To reliably represent a position or range within a document, it is more effective to leverage the unique ID of each item/character in a List CRDT or Text CRDT.
Loro optimizes State metadata by not storing the IDs of deleted elements. This approach complicates tracking cursors since they rely on these IDs. The solution recalculates position by replaying relevant history to update stable positions accurately. To minimize the performance impact of history replay, the system updates cursor info to reference only the IDs of currently present elements, thereby reducing the need for replay.
pub fn to_vec(&self) -> Vec<LoroValue>
pub fn clear(&self) -> LoroResult<()>
pub fn is_deleted(&self) -> bool
pub fn get_creator_at(&self, index: u32) -> Option<PeerID>
pub fn get_last_mover_at(&self, index: u32) -> Option<PeerID>
pub fn get_last_editor_at(&self, index: u32) -> Option<PeerID>
pub fn doc(&self) -> Option<Arc<LoroDoc>>
pub fn subscribe( &self, subscriber: Arc<dyn Subscriber>, ) -> Option<Arc<Subscription>>